/**********************************************************
This program uses restricted access retail scanner data

Used to create:
(1) Figure 5A and 5B
(2) Appendix Table 3
************************************************************/

/*************************************************************************
Appendix Table 3: Effect of Tax Policy on Store Volume and Basket Size
**************************************************************************/
* store-day scanner data
clear
set more off

use "../Raw/Scaner Data/storedate_all", clear

drop if maxyear<2012 //keep only stores with data through 2012
drop if date==mdy(2,6,2010) | date==mdy(2,10,2010) //blizzard dates - likely store closure

label var numtxn "Number of transactions by store-day"
label var totexp_date "Total expenditure by store-day"
label var avgnumprod_date "Average number of items per transaction by store-day"

xtset store_id

gen post1=(date>=mdy(1,1,2010))
gen post2=(date>=mdy(1,1,2012))
gen post1Xdc=post1*dc
gen post2Xmd=post2*md
label var post1 "=1 if after DC tax implemented"
label var post2 "=1 if after MD tax implemented"

gen month=month(date)
xi i.month, prefix(M)
xi i.year, prefix(Y)

gen lnumtxn=log(numtxn)
xtreg lnumtxn post1Xdc post2Xmd M* Y*, vce(cluster store_id) fe
estimates save "./estimates/app3_lnumtxn.ster", replace

gen ltotexp=log(totexp_date)
xtreg ltotexp post1Xdc post2Xmd Y* M*, vce(cluster store_id) fe
estimates save "./estimates/app3_ltotexp.ster", replace

gen lavgnumprod=log(avgnumprod_date)
xtreg lavgnumprod post1Xdc post2Xmd Y* M*, vce(cluster store_id) fe
estimates save "./estimates/app3_lavgnumprod.ster", replace

/***************************************************************************************
Figure 5: Proportion of Customers Using a Disposable Bag After Implementation of the Tax
****************************************************************************************/
* UPC-by-transaction level scanner data
foreach state in DC MD {
use storetxnupc_`state'post, clear

label var txn_id "Transaction ID"
label var upc_id "UPC ID"
label var net_amt "Net amount spent on UPC by txn"
label var iqty "Number of items purchased by txn-UPC"

gen tax=1 if upc_id==49941062001
replace tax=0 if tax==.
label var tax "=1 if transaction charged a bag tax"

gen item=1 if net_amt>=0 & iqty>0
bysort txn_id: egen numitem=total(item)
drop if numitem==0 //drop txns with no items purchased

collapse (sum) tax, by(txn_id date)
collapse (mean) pct_tax=tax, by(date)

drop if date==mdy(2,6,2010) | date==mdy(2,10,2010) | date==mdy(9,18,2011) //blizzard dates & one anomaly
twoway (line pct_tax date)
}
